@@ -3,6 +3,12 @@
 #' Search for videos, channels and playlists. (By default, the function searches for videos.)
 #' 
 #' @param term Character. Search term; required; no default
+#' For using Boolean operators, see the API documentation. Here's some of the relevant information:
+#' "Your request can also use the Boolean NOT (-) and OR (|) operators to exclude videos or to 
+#' find videos that are associated with one of several search terms. For example, to search 
+#' for videos matching either "boating" or "sailing", set the q parameter value to boating|sailing. 
+#' Similarly, to search for videos matching either "boating" or "sailing" but not "fishing", 
+#' set the q parameter value to boating|sailing -fishing"
 #' @param max_results Maximum number of items that should be returned. Integer. Optional. Can be between 0 and 50. Default is 50.
 #' Search results are constrained to a maximum of 500 videos if type is video and we have a value of \code{channel_id}.
 #' @param channel_id Character. Only return search results from this channel; Optional.
@@ -103,7 +109,9 @@ yt_search <- function (term = NULL, max_results = 50, channel_id = NULL,
   querylist <- list(part = "snippet", q = format_term, maxResults = max_results,
                     channelId = channel_id, type = type,
                     channelType = channel_type, eventType = event_type,
-                    location = location, publishedAfter = published_after,
+                    location = location,
+                    locationRadius = location_radius,
+                    publishedAfter = published_after,
                     publishedBefore = published_before,
                     videoDefinition = video_definition,
                     videoCaption = video_caption,
